@@ -49,14 +49,12 @@ class Model_Size:
 
 MODEL_SIZE_NAMES = [f.name for f in fields(Model_Size)]
 
-MODEL_FOR_SEQUENCE_CLASSIFICATION_MAPPINGX = MODEL_FOR_SEQUENCE_CLASSIFICATION_MAPPING.setdefault(ElectraConfig,
-                                                                                                  ElectraForSequenceClassificationX
-                                                                                                  )
+MODEL_FOR_SEQUENCE_CLASSIFICATION_MAPPING[ElectraConfig] = ElectraForSequenceClassificationX
 
 all_model_mappings = OrderedDict([(Model_Task_Type.base, MODEL_MAPPING),
                                   (Model_Task_Type.lm_head, MODEL_WITH_LM_HEAD_MAPPING),
                                   (Model_Task_Type.token_cls, MODEL_FOR_TOKEN_CLASSIFICATION_MAPPING),
-                                  (Model_Task_Type.seq_cls, MODEL_FOR_SEQUENCE_CLASSIFICATION_MAPPINGX),
+                                  (Model_Task_Type.seq_cls, MODEL_FOR_SEQUENCE_CLASSIFICATION_MAPPING),
                                   (Model_Task_Type.qa, MODEL_FOR_QUESTION_ANSWERING_MAPPING),
                                   (Model_Task_Type.pretrain, MODEL_FOR_PRETRAINING_MAPPING),
                                   (Model_Task_Type.multi_choice, MODEL_FOR_MULTIPLE_CHOICE_MAPPING)
